# Load packages ####
library(openxlsx)
library(readxl)
library(dplyr)
library(tidyr)
library(rgdal)
library(raster)
library(sf)
library(latticeExtra)
library(sp)
library(maptools)
library(rasterVis)
library(RColorBrewer)
library(ggplot2)
library(ggpubr)
library(ncdf4)
library(tmap)
library(tidyverse)
library(viridis)
library(GGally)
library(visreg)

# Load the compiled data ####
# PlotID is the PlotObservationID from sPlotOpen
# noR is the abundance of the nonresprouters 
# R is the abundance of resprouter
# naR is the abundance of woody species without resprouting information
# region includes aus (Australia) and eu (Europe)
# modis, cci51, cci10lt, model -- datasets used to derive the FRI 
# gpp -- p-model gpp
# grass -- grass cover (herb cover) from ESACCI landcover

euaus.cover<- st_read("Combined_data.shp")
colnames(euaus.cover)<- c("PlotObservationID", "no","yes","none","region", 
                          "modisfri.0.25", "ccifri.0.25", "ccilt10fri.0.25","fri.oli", 
                          "gpp.total","cci.herb" ,"geometry")

# Add p1(resprouter) ####
euaus.cover<- euaus.cover %>%
  mutate(per_yes=yes/sum(yes,no, na.rm = T))
# Add p2(resprouter) ####
euaus.cover<- euaus.cover %>% 
  mutate(per_yes2=yes/sum(yes,no,none, na.rm = T))
# Add relative known abundance ####
euaus.cover<- euaus.cover %>% 
  mutate(known_cover=sum(yes,no, na.rm = T)/sum(yes,no,none, na.rm = T))

# Box plots ####
euaus.cover$fri.log<- log(euaus.cover$modisfri.0.25) # (supplement: choose "ccifri.0.25", "ccilt10fri.0.25", "fri.oli")

box.plot<- euaus.cover %>% 
  mutate(per_yes=per_yes) %>% 
  # filter(region=="eu") %>% (supplement: set "eu" or "aus" to get box plot for each continent)
  filter(fri.log>0) %>%
  drop_na(fri.log) %>% arrange(fri.log) %>%
  drop_na(fri.log) %>%
  mutate(rt = fri.log) %>%
  mutate(rt = replace(rt, fri.log>=0 & fri.log<3, "0-3")) %>%
  mutate(rt = replace(rt, fri.log>=3 & fri.log<4, "3-4")) %>%
  mutate(rt = replace(rt, fri.log>=4 & fri.log<5, "4-5")) %>%
  mutate(rt = replace(rt, fri.log>=5 & fri.log<6, "5-6")) %>%
  mutate(rt = replace(rt, fri.log>=6 & fri.log<7, "6-7")) %>%
  mutate(rt = replace(rt, fri.log>7 & fri.log<9, "7-9"))
# The groups also can be set to suit different FRI data and regions. 

box.plot$rt <- factor(box.plot$rt, 
                      levels = unique(box.plot$rt))
group.number<- box.plot %>% drop_na(per_yes) %>% group_by(rt) %>% summarise(n=n())
group.number$rt <- factor(group.number$rt, 
                          levels = unique(group.number$rt))

## kruskal test for median values ####
kruskal.test(per_yes ~ rt, data = box.plot)
wilcox.model<-pairwise.wilcox.test(box.plot$per_yes, box.plot$rt,
                                   p.adjust.method = "BH")
library(multcompView)
tri.to.squ<-function(x)
{
  rn<-row.names(x)
  cn<-colnames(x)
  an<-unique(c(cn,rn))
  myval<-x[!is.na(x)]
  mymat<-matrix(1,nrow=length(an),ncol=length(an),dimnames=list(an,an))
  for(ext in 1:length(cn))
  {
    for(int in 1:length(rn))
    {
      if(is.na(x[row.names(x)==rn[int],colnames(x)==cn[ext]])) next
      mymat[row.names(mymat)==rn[int],colnames(mymat)==cn[ext]]<-x[row.names(x)==rn[int],colnames(x)==cn[ext]]
      mymat[row.names(mymat)==cn[ext],colnames(mymat)==rn[int]]<-x[row.names(x)==rn[int],colnames(x)==cn[ext]]
    }
    
  }
  return(mymat)
}
mymat<-tri.to.squ(wilcox.model$p.value)
myletters<-multcompLetters(mymat,compare="<=",threshold=0.05,Letters=letters)
myletters

kruskal.test<- as.data.frame(myletters$Letters)
kruskal.test<- tibble::rownames_to_column(kruskal.test, "rt")
colnames(kruskal.test) <- c("rt", "letter")
kruskal.test$rt <- factor(kruskal.test$rt, 
                          levels = unique(kruskal.test$rt))

## t test for mean values ####
ttest.model<- pairwise.t.test(box.plot$per_yes, box.plot$rt,
                              p.adjust.method = "BH")
ttest.mymat<-tri.to.squ(ttest.model$p.value)
ttest.myletters<-multcompLetters(ttest.mymat,compare="<=",threshold=0.05,Letters=letters)
ttest.myletters

t.test<- as.data.frame(ttest.myletters$Letters)
t.test<- tibble::rownames_to_column(t.test, "rt")
colnames(t.test) <- c("rt", "letter")
t.test$rt <- factor(t.test$rt, 
                    levels = unique(t.test$rt))

# Plot the relationship ####
box.plot %>% drop_na(per_yes) %>%   
  left_join(kruskal.test) %>% ggplot(aes(per_yes, rt))+
  geom_boxplot(outlier.shape = NA)+ 
  geom_point(size=1, alpha=0.1, col="blue", position=position_jitter(h=0.1))+ 
  stat_summary(fun=mean,shape=21,size=2,col='red',fill="#e63946", geom='point')+
  xlab("Proportion of Resprouters")+ # R+/R++R-+R?
  ylab("ln(Fire return interval (yrs))")+
  coord_cartesian(xlim=c(0,1.3))+
  theme_bw()+
  ggtitle("MODIS") + #FireCCI51 FireCCI10LT Model prediction
  theme(axis.text = element_text(size = rel(1.1))) +
  theme(axis.title = element_text(size = rel(1.1)))+ #, face = 'bold'+
  annotate("text", x = 1.05, y=t.test$rt, label = t.test$letter,size = 5, fontface='italic', color="red")+
  annotate("text", x = 1.12, y=kruskal.test$rt, label = kruskal.test$letter,size = 5, fontface='italic')+
  annotate("text", x = 1.25, y=group.number$rt, label = paste0("(", group.number$n, ")"),size = 5, fontface='italic')

# GLM ####
target<- euaus.cover %>% st_drop_geometry() %>%
  # filter(region == "eu") %>% (supplement: test different regions)
  # filter(known_cover < 1) %>% (supplement: test the impact of known abundance)
  dplyr::select(
    "per_yes",
    "modisfri.0.25",
    "gpp.total", 
    "cci.herb") %>%  
  drop_na() 

colnames(target) <- c("PlotObservationID", "cover.R",
                      "fire.return.interval",
                      "gpp",
                      "herb.cover") 

## tranformation to reduce skewness ####
target$gpp<- log(target$gpp)
target$fire.return.interval<- log(target$fire.return.interval)
target$herb.cover<- target$herb.cover
target<- target %>% filter_all(all_vars(!is.infinite(.)))

glm.qb <- glm(cover.R ~  fire.return.interval+
                gpp+
                herb.cover,
              data = target, family = 'binomial') 

summ(glm.qb, vifs = T)

# Partial residual plots ####
library(MASS)
get_density <- function(x, y, ...) {
  dens <- MASS::kde2d(x, y, ...)
  ix <- findInterval(x, dens$x)
  iy <- findInterval(y, dens$y)
  ii <- cbind(ix, iy)
  return(dens$z[ii])
}

# visreg version https://github.com/pbreheny/visreg/issues/56
# replace "herb.cover" to "GPP" or "fire.return.interval" to get other figures 
v <- visreg(glm.qb, "herb.cover", plot=FALSE)
v$res$herb.cover<- target$herb.cover
v$res$density <- get_density(v$res$herb.cover, v$res$visregRes, n = 100)
v$res %>% 
  ggplot(aes(x=herb.cover, y=visregRes)) +
  geom_point(aes(color=density)) +
  scale_colour_gradientn(
    colors = c("#E5E8E8", "#F1C40F","#E74C3C", "#154360"),
    values = scales::rescale(c(0, 0.05, 0.075, 0.10, 0.15, 0.20, 0.3, 0.5)) 
  )+
  geom_smooth(method = "lm", se = F, color = "#44403F", linetype="dashed", lwd=0.6) +
  xlab("Herb cover") +
  ylab("Log odds (proportion of resprouters)") +
  ggtitle("Resprouter/Resprouter+Nonresprouter") +#  All woody cover
  theme_bw()
### figure size: w=4.96 h=4.23

# Locations of the plots (Figure 1) ####

# Basic map of boundaries of countries downloaded from https://www.naturalearthdata.com/downloads/110m-cultural-vectors/110m-admin-0-countries/
world<- read_sf("ne_110m_admin_0_countries/ne_110m_admin_0_countries.shp")

# Regions map 
ausregion <- as(extent(108, 156, -44, -8), 'SpatialPolygons')
crs(ausregion) <- "+proj=longlat +datum=WGS84 +no_defs"

euregion <- as(extent(-25, 65, 35, 72), 'SpatialPolygons')
crs(euregion) <- "+proj=longlat +datum=WGS84 +no_defs"

## Australia 
aus.map<- world %>% filter(ADMIN %in% "Australia")
aus_outline <- as(st_geometry(aus.map), Class="Spatial")
## Europe 
world_outline <- as(st_geometry(world), Class="Spatial")
eu_outline <- crop(world_outline, euregion)

## rasterize to get the density map
r<- raster(ncol=720, nrow=360, xmn=-180, xmx=180, ymn=-90, ymx=90)
count.rasterize<-rasterize(euaus.cover,r,field="PlotObservationID",fun='count', na.rm = T)  
aus.count <- crop(count.rasterize, ausregion)
eu.count <- crop(count.rasterize, euregion)

coul <- plasma(20)
aus.plt<- levelplot(aus.count, margin=F, col.regions = coul, 
                    at= c(0, 10, 50, 100, 600), 
                    colorkey = list(space = "bottom", labels = list(at = c(0, 10, 50, 100, 600),
                                                                    labels =c("0", "10", "50", "100", " "))))

aus.plt + latticeExtra::layer(sp.lines(aus_outline, col="gray30", lwd=1))

eu.plt<- levelplot(eu.count, margin=F, col.regions = coul, 
                   at= c(0, 10, 50, 100, 600), 
                   colorkey = list(space = "bottom", labels = list(at = c(0, 10, 50, 100, 600),
                                                                   labels =c("0", "10", "50", "100", " "))))

eu.plt + latticeExtra::layer(sp.lines(eu_outline, col="gray30", lwd=1))

## the color bar used in Figure 1 is made manually.

# Summary of resprouting information for woody species (Table 1) ####
# Overview of resprouting information in Australia (Table 1)
aus.species.target<- read.csv("aus_species_target.csv")
aus.species.target %>% ggplot(aes(as.factor(Resprouter))) + 
  geom_bar()+ 
  geom_text(stat='count', aes(label=..count..), vjust=-0.5)+
  theme_bw()+
  xlab("Resprouting information in Australia") +
  theme(axis.text.x = element_text(vjust = 0.5, hjust=1))

# Overview of resprouting information in Europe (Table 1)
eu.species.target<- read.csv("eu_species_target.csv")
eu.species.target %>% ggplot(aes(as.factor(Resprouter))) + 
  geom_bar()+ 
  geom_text(stat='count', aes(label=..count..), vjust=-0.5)+
  theme_bw()+
  xlab("Resprouting information in Europe") +
  theme(axis.text.x = element_text(vjust = 0.5, hjust=1))

# Produce woody species classification list (Appendix 1, Table 1) ####
species.target<- rbind(aus.species.target,eu.species.target)
species.target <- species.target %>% drop_na() %>% distinct()
write.csv(species.target, "woody_species_resprout_classification.csv", row.names = F)
